.BG
.FN predict.hazcov
.TL
Hazard (and log hazard ratio) estimates from hazcov objects
.DN
Predict method for `hazcov' objects
.CS
predict.hazcov(z, newdata, se.fit=F, lrr=F, baseline, mlr=-log(4), 
               minpr=z$minpr)
.RA
.AG z
Object of class `"hazcov"' (output from function `hazcov()')
.AG newdata
Data frame containing new covariate and time values where estimates are to be
computed.  The names in newdata must correspond to the names in `z$midp'.
.OA
.AG se.fit
If `T', calculates standard errors for the hazard estimates.
.AG lrr
If `T', calculates log hazard ratios in addition to the hazard estimates.
.AG baseline
baseline value of covariates for computation of hazard ratios.  Default tries
to choose a value where hazard estimate is defined on all intervals.
.AG mlr
The minimum value for log hazard ratios.  The log ratios are truncated at +/-
this value.  (Must be < 0.)
.AG minpr
hazard estimates will only be given where the smoothed estimates in the
denominator (roughly of the probability of still being at risk) are >= this
value (if `ls=F'). 
.RT
If `se.fit==lrr==F', a vector giving the hazard estimates at the points in
newdata.  Otherwise a data frame with columns `haz' giving the hazard
estimates, `logratio' giving the log hazard ratios (if `lrr=T'), and `se'
giving the standard errors of the hazard estimates (if `se.fit=T').
.DT
The names of newdata must correspond to the names in `z$midp', which
might not be exactly the same as the names in the formula in the original
call to `hazcov'.  For example,	`log(cov)' in the original call would be 
`log.cov.' in `z$midp', and values on the log scale would need to be given in
newdata. 

Standard errors are computed as discussed in the references below.
Calculation of standard errors tends to run out of memory if `nrow(z$bin)' is
very large.
.SH REFERENCES

Gray RJ (1996) Hazard rate regression using ordinary nonparametric regression
smoothers, JCGS 5:190-207.
.PP
Gray RJ (1994) Hazard estimation with covariates: algorithms for direct
estimation, local scoring and backfitting, Technical Report 784Z, Div of
Biostatistics, Dana-Farber Cancer Institute. 
.SA
`hazcov'
.EX
z <- hazcov(cbind(TTR,Fail.Ind)~ER+Log.Nodes+Tumor.Size,data=jd,span=.20)
x <- expand.grid(Time=seq(.5,10,length=30),ER=as.factor("Pos"),
       Log.Nodes=log(c(1,3,6,10)),Tumor.Size=c(2,4,7))
zp <- predict(z,x)
.KW survival
.KW hazcov
.WR
